@@ -512,6 +512,8 @@ class ClassificationApp:
             source=self.w_dist_source.param.value
         )
         def plot_dist(a, dist_type, var, source):
+            if a != 2:
+                return ""
             mask = self.select_instances()
             output_col = self.output_col
 
@@ -585,6 +587,8 @@ class ClassificationApp:
     def render_explorer_panel(self):
         @pn.depends(a=self.tabs.param.active, x=self.w_var_x, y=self.w_var_y, c=self.w_var_c.param.value)
         def plot_scatter(a, x, y, c):
+            if a != 3:
+                return ""
             mask = self.select_instances()
             output_col = self.output_col
             df_all = self.workspace.data[mask].copy()
@@ -659,10 +663,11 @@ class ClassificationApp:
             font_url="https://fonts.googleapis.com/css2?family=Source+Sans+Pro",
             main_layout='',
             # sidebar_footer="Info",
-            favicon=str(_my_path / "../docs/source/imgs/blobs.svg"),
+            favicon=str(_my_path / "midia/blobs.svg"),
             background_color='#F8F8F9',
             sidebar_width=285,
-            theme_toggle=False
+            theme_toggle=False,
+            meta_author='Pedro Paiva'
         )
 
         return fast_list
