@@ -1,14 +1,15 @@
 """
-Hyper-parameter optimization (HPO) module. It is implemented on top of `hyperopt`, which is a Bayesian optimization
-Python package.
+Hyperparameter optimization (HPO) module. It is implemented on top of `hyperopt <http://hyperopt.github.io/hyperopt/>`_,
+which is a Bayesian optimization Python package.
 """
 
 import sys
+from typing import Any, Dict, Optional, Type, Union
 
 import numpy as np
 from hyperopt import hp, tpe, fmin, space_eval, STATUS_OK
 from hyperopt.pyll import scope
-from sklearn.base import is_classifier, is_regressor
+from sklearn.base import is_classifier, is_regressor, ClassifierMixin, RegressorMixin
 from sklearn.model_selection import cross_val_score
 
 _progressbar = True
@@ -19,13 +20,29 @@ def set_hyperopt_progressbar(flag: bool):
     _progressbar = flag
 
 
-def classifier_hp_space(name, **kwargs):
+def predictor_hp_space(name: str, **kwargs) -> Dict[str, Any]:
+    """
+    This function returns the predictor hyperparameter space, which will be searched to find the best parameters,
+    given the training set.
+
+    Args:
+        name: the predictor name
+        **kwargs: extra parameters
+
+    Returns:
+        dict: The predictor hyperparameter space
+    """
     func = getattr(sys.modules[__name__], f"_{name}_hp_space")
     return func(**kwargs)
 
 
-def _objective(predictor, params, X, y):
-    predictor = predictor(**params)
+def _objective(
+        predictor: Union[Type[ClassifierMixin], Type[RegressorMixin]],
+        params: Dict[str, Any],
+        X: np.ndarray,
+        y: np.ndarray
+) -> Dict[str, Any]:
+    predictor = predictor(**params)  # noqa
     if is_classifier(predictor):
         score = cross_val_score(predictor, X, y, cv=3, scoring='f1_micro', n_jobs=None).mean()
     elif is_regressor(predictor):
@@ -35,13 +52,38 @@ def _objective(predictor, params, X, y):
     return {'loss': -score, 'status': STATUS_OK}
 
 
-def find_best_params(name, predictor, fixed_params, X, y, max_evals=100, hpo_timeout=90):
+def find_best_params(
+        name: str,
+        predictor: Union[Type[ClassifierMixin], Type[RegressorMixin]],
+        fixed_params: Optional[Dict[str, Any]],
+        X: np.ndarray,
+        y: np.ndarray,
+        max_evals: int = 100,
+        hpo_timeout: int = 90
+) -> Dict[str, Any]:
+    r"""
+    Find the best solution searched over the hyperparameter space, minimizing a cross validation score function. It uses
+    a Bayesian Optimization like method.
+
+    Args:
+        name (str): the algorithm name, from which the search space is inferred
+        predictor: a scikit-learn predictor class
+        fixed_params (dict): set of parameters that will not be optimized
+        X (np.ndarray): the training dataset
+        y (np.ndarray): the target values
+        max_evals (int): maximum number of evaluations
+        hpo_timeout (int): timeout value; the search ends when either :math:`\sharp evals > max\_evals`
+            or :math:`spent\_time > hpo\_timeout`
+
+    Returns:
+        dict: The best hyperparameters found
+    """
     # TODO: timeout proportional to number of instances
 
     def objective(params):
         return _objective(predictor, params, X, y)
 
-    space = classifier_hp_space(name)
+    space = predictor_hp_space(name)
     space = {**space, **fixed_params}
     best = fmin(fn=objective, space=space, algo=tpe.suggest, max_evals=max_evals,
                 show_progressbar=_progressbar, timeout=hpo_timeout)
