@@ -23,7 +23,7 @@ from sklearn.svm import SVR, NuSVR, LinearSVR
 from sklearn.tree import DecisionTreeRegressor
 
 from . import metrics
-from .base import Learner
+from .base import LearnersPool
 from .hpo import find_best_params
 
 _reg_dict = {
@@ -51,7 +51,7 @@ _overlap_params = {
 }
 
 
-class Regressor(Learner):
+class Regressor(LearnersPool):
     def __init__(self, data: pd.DataFrame, cv=10, output_col=None):
         super().__init__()
         self.logger = logging.getLogger(__name__)
